EXPORTS
	?SetParameterL@CHtiCfg@@QAEHABVTDesC8@@0@Z @ 1 NONAME ; int CHtiCfg::SetParameterL(class TDesC8 const &, class TDesC8 const &)
	?NewLC@CHtiCfg@@SAPAV1@XZ @ 2 NONAME ; class CHtiCfg * CHtiCfg::NewLC(void)
	?LoadCfgL@CHtiCfg@@QAEXABVTDesC16@@0@Z @ 3 NONAME ; void CHtiCfg::LoadCfgL(class TDesC16 const &, class TDesC16 const &)
	??1CHtiCfg@@UAE@XZ @ 4 NONAME ; CHtiCfg::~CHtiCfg(void)
	?GetParameterL@CHtiCfg@@QAE?AVTPtrC8@@ABVTDesC8@@@Z @ 5 NONAME ; class TPtrC8 CHtiCfg::GetParameterL(class TDesC8 const &)
	?GetParameterIntL@CHtiCfg@@QAEHABVTDesC8@@@Z @ 6 NONAME ; int CHtiCfg::GetParameterIntL(class TDesC8 const &)
	?SaveCfgL@CHtiCfg@@QAEXABVTDesC16@@0@Z @ 7 NONAME ; void CHtiCfg::SaveCfgL(class TDesC16 const &, class TDesC16 const &)
	?RemoveParameterL@CHtiCfg@@QAEHABVTDesC8@@@Z @ 8 NONAME ; int CHtiCfg::RemoveParameterL(class TDesC8 const &)
	?NewL@CHtiCfg@@SAPAV1@XZ @ 9 NONAME ; class CHtiCfg * CHtiCfg::NewL(void)

